# Credits

## Original Author

- [Krzysztof Dorosz](https://github.com/cypreess)

## Development Lead

- [Dominik Kozaczko](https://github.com/dekoza)

## Contributors

Please see <https://github.com/django-getpaid/django-getpaid/graphs/contributors>

## Sponsors

Many thanks to [Sunscrapers](http://sunscrapers.com/) for sponsoring development since version 1.8.
